@@ -119,9 +119,9 @@ Kanagram::Kanagram() : TQWidget(0, 0, WStaticContents | WNoAutoErase), m_overNex
 	m_inputBox->setGeometry(TQRect(52, 427, 273, 29));
 	m_inputBox->setFrame(false);
 	
-	connect(m_inputBox, TQT_SIGNAL(returnPressed()), this, TQT_SLOT(checkWord()));
-	connect(m_hintTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(hideHint()));
-	connect(m_inputBox, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(update()));
+	connect(m_inputBox, TQ_SIGNAL(returnPressed()), this, TQ_SLOT(checkWord()));
+	connect(m_hintTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(hideHint()));
+	connect(m_inputBox, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(update()));
 	
 	TQFont f = TQFont();
 	f.setPointSize(17);
@@ -432,7 +432,7 @@ void Kanagram::mousePressEvent(TQMouseEvent *e)
 
 	if(m_switcherRect.contains(e->pos()) || m_arrowRect.contains(e->pos()))
 	{
-		if(!(e->button() == Qt::RightButton))
+		if(!(e->button() == TQt::RightButton))
 			m_game->nextVocab();
 		else
 			m_game->previousVocab();
@@ -465,7 +465,7 @@ void Kanagram::mousePressEvent(TQMouseEvent *e)
 		{
 			if(m_useSounds) play("right.ogg");
 			m_inputBox->setPaletteBackgroundColor(TQColor(0, 255, 0));
-			TQTimer::singleShot(1000, this, TQT_SLOT(resetInputBox()));
+			TQTimer::singleShot(1000, this, TQ_SLOT(resetInputBox()));
 			m_inputBox->clear();
 			hideHint();
 			m_game->nextAnagram();
@@ -475,7 +475,7 @@ void Kanagram::mousePressEvent(TQMouseEvent *e)
 		{
 			if(m_useSounds) play("wrong.ogg");
 			m_inputBox->setPaletteBackgroundColor(TQColor(255, 0, 0));
-			TQTimer::singleShot(1000, this, TQT_SLOT(resetInputBox()));
+			TQTimer::singleShot(1000, this, TQ_SLOT(resetInputBox()));
 			m_inputBox->clear();
 			update();
 		}
@@ -723,7 +723,7 @@ void Kanagram::drawTextNew(TQPainter &p, const TQString &text, int textAlign, in
 void Kanagram::checkWord()
 {
 	TQPoint p = m_upRect.topLeft() + TQPoint( 1, 1 );
-	TQMouseEvent *e = new TQMouseEvent( TQEvent::MouseButtonPress, p, Qt::LeftButton, Qt::NoButton );
+	TQMouseEvent *e = new TQMouseEvent( TQEvent::MouseButtonPress, p, TQt::LeftButton, TQt::NoButton );
 	mousePressEvent(e);
 }
 
@@ -744,8 +744,8 @@ void Kanagram::showSettings()
 	m_vocabSettings = new VocabSettings( configDialog );
 	configDialog->addPage( m_vocabSettings, i18n("Vocabularies"), "edit" );
 	configDialog->addPage( new NewStuff( configDialog ), i18n("New Stuff"), "knewstuff" );
-	connect(configDialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(loadSettings()));
-	connect(configDialog, TQT_SIGNAL(applyClicked()), this, TQT_SLOT(refreshVocabularies()));
+	connect(configDialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(loadSettings()));
+	connect(configDialog, TQ_SIGNAL(applyClicked()), this, TQ_SLOT(refreshVocabularies()));
 	configDialog->exec();
 	delete configDialog;
 }
