@@ -84,9 +84,9 @@ MainDlg::MainDlg(TQWidget *parentWidget, const char *, TQObject *parent, const c
 	coordsDialog = 0;
 	m_popupmenu = new TDEPopupMenu(parentWidget);
 	view = new View( m_readonly, m_modified, m_popupmenu, parentWidget );
-	connect( view, TQT_SIGNAL( setStatusBarText(const TQString &)), this, TQT_SLOT( setReadOnlyStatusBarText(const TQString &) ) );
+	connect( view, TQ_SIGNAL( setStatusBarText(const TQString &)), this, TQ_SLOT( setReadOnlyStatusBarText(const TQString &) ) );
 	setWidget( view );
-	view->setFocusPolicy(TQ_ClickFocus);
+	view->setFocusPolicy(TQWidget::ClickFocus);
 	minmaxdlg = new KMinMax(view, m_parent);
 	view->setMinMaxDlg(minmaxdlg);
 	m_quickEdit = new KLineEdit( parentWidget );
@@ -109,8 +109,8 @@ MainDlg::MainDlg(TQWidget *parentWidget, const char *, TQObject *parent, const c
 	m_settingsDialog->addPage( m_constantsSettings, i18n("Constants"), "editconstants", i18n("Constants") );
 	// User edited the configuration - update your local copies of the
 	// configuration data
-	connect( m_settingsDialog, TQT_SIGNAL( settingsChanged() ), this, TQT_SLOT(updateSettings() ) );
-    connect( view, TQT_SIGNAL( resetZoom() ), this, TQT_SLOT(resetZoom() ) );
+	connect( m_settingsDialog, TQ_SIGNAL( settingsChanged() ), this, TQ_SLOT(updateSettings() ) );
+    connect( view, TQ_SIGNAL( resetZoom() ), this, TQ_SLOT(resetZoom() ) );
 }
 
 MainDlg::~MainDlg()
@@ -123,29 +123,29 @@ MainDlg::~MainDlg()
 void MainDlg::setupActions()
 {
 	// standard actions
-	m_recentFiles = KStdAction::openRecent( this, TQT_SLOT( slotOpenRecent( const KURL& ) ), actionCollection(),"file_openrecent");
-	KStdAction::print( this, TQT_SLOT( slotPrint() ), actionCollection(),"file_print" );
-	KStdAction::save( this, TQT_SLOT( slotSave() ), actionCollection() );
-	KStdAction::saveAs( this, TQT_SLOT( slotSaveas() ), actionCollection() );
-	connect( kapp, TQT_SIGNAL( lastWindowClosed() ), kapp, TQT_SLOT( quit() ) );
+	m_recentFiles = KStdAction::openRecent( this, TQ_SLOT( slotOpenRecent( const KURL& ) ), actionCollection(),"file_openrecent");
+	KStdAction::print( this, TQ_SLOT( slotPrint() ), actionCollection(),"file_print" );
+	KStdAction::save( this, TQ_SLOT( slotSave() ), actionCollection() );
+	KStdAction::saveAs( this, TQ_SLOT( slotSaveas() ), actionCollection() );
+	connect( kapp, TQ_SIGNAL( lastWindowClosed() ), kapp, TQ_SLOT( quit() ) );
 
-	TDEAction *prefs  = KStdAction::preferences( this, TQT_SLOT( slotSettings() ), actionCollection());
+	TDEAction *prefs  = KStdAction::preferences( this, TQ_SLOT( slotSettings() ), actionCollection());
 	prefs->setText( i18n( "Configure KmPlot..." ) );
-	KStdAction::keyBindings(this, TQT_SLOT(optionsConfigureKeys()), actionCollection());
-	KStdAction::configureToolbars(this, TQT_SLOT(optionsConfigureToolbars()), actionCollection());
+	KStdAction::keyBindings(this, TQ_SLOT(optionsConfigureKeys()), actionCollection());
+	KStdAction::configureToolbars(this, TQ_SLOT(optionsConfigureToolbars()), actionCollection());
 
 
 	// KmPlot specific actions
 	// file menu
-	( void ) new TDEAction( i18n( "E&xport..." ), 0, this, TQT_SLOT( slotExport() ), actionCollection(), "export");
+	( void ) new TDEAction( i18n( "E&xport..." ), 0, this, TQ_SLOT( slotExport() ), actionCollection(), "export");
 
 	//zoom menu
-	m_mnuNoZoom = new TDERadioAction(i18n("&No Zoom") ,"CTRL+0",TQT_TQOBJECT(view), TQT_SLOT( mnuNoZoom_clicked() ),actionCollection(),"no_zoom" );
-	TDERadioAction * mnuRectangular = new TDERadioAction(i18n("Zoom &Rectangular"), "zoom-fit-best", "CTRL+1",TQT_TQOBJECT(view), TQT_SLOT( mnuRectangular_clicked() ),actionCollection(),"zoom_rectangular" );
-	TDERadioAction * mnuZoomIn = new TDERadioAction(i18n("Zoom &In"), "zoom-in", "CTRL+2",TQT_TQOBJECT(view), TQT_SLOT( mnuZoomIn_clicked() ),actionCollection(),"zoom_in" );
-	TDERadioAction * mnuZoomOut = new TDERadioAction(i18n("Zoom &Out"), "zoom-out", "CTRL+3",TQT_TQOBJECT(view), TQT_SLOT( mnuZoomOut_clicked() ),actionCollection(),"zoom_out" );
-	TDERadioAction * mnuZoomCenter = new TDERadioAction(i18n("&Center Point") ,"CTRL+4",TQT_TQOBJECT(view), TQT_SLOT( mnuCenter_clicked() ),actionCollection(),"zoom_center" );
-	(void ) new TDEAction(i18n("&Fit Widget to Trigonometric Functions") ,0,TQT_TQOBJECT(view), TQT_SLOT( mnuTrig_clicked() ),actionCollection(),"zoom_trig" );
+	m_mnuNoZoom = new TDERadioAction(i18n("&No Zoom") ,"CTRL+0",view, TQ_SLOT( mnuNoZoom_clicked() ),actionCollection(),"no_zoom" );
+	TDERadioAction * mnuRectangular = new TDERadioAction(i18n("Zoom &Rectangular"), "zoom-fit-best", "CTRL+1",view, TQ_SLOT( mnuRectangular_clicked() ),actionCollection(),"zoom_rectangular" );
+	TDERadioAction * mnuZoomIn = new TDERadioAction(i18n("Zoom &In"), "zoom-in", "CTRL+2",view, TQ_SLOT( mnuZoomIn_clicked() ),actionCollection(),"zoom_in" );
+	TDERadioAction * mnuZoomOut = new TDERadioAction(i18n("Zoom &Out"), "zoom-out", "CTRL+3",view, TQ_SLOT( mnuZoomOut_clicked() ),actionCollection(),"zoom_out" );
+	TDERadioAction * mnuZoomCenter = new TDERadioAction(i18n("&Center Point") ,"CTRL+4",view, TQ_SLOT( mnuCenter_clicked() ),actionCollection(),"zoom_center" );
+	(void ) new TDEAction(i18n("&Fit Widget to Trigonometric Functions") ,0,view, TQ_SLOT( mnuTrig_clicked() ),actionCollection(),"zoom_trig" );
 	m_mnuNoZoom->setExclusiveGroup("zoom_modes");
     m_mnuNoZoom->setChecked(true);
 	mnuRectangular->setExclusiveGroup("zoom_modes");
@@ -154,52 +154,52 @@ void MainDlg::setupActions()
 	mnuZoomCenter->setExclusiveGroup("zoom_modes");
 
 	// help menu
-	( void ) new TDEAction( i18n( "Predefined &Math Functions" ), "functionhelp", 0, this, TQT_SLOT( slotNames() ), actionCollection(), "names" );
+	( void ) new TDEAction( i18n( "Predefined &Math Functions" ), "functionhelp", 0, this, TQ_SLOT( slotNames() ), actionCollection(), "names" );
 
 	// edit menu
-	( void ) new TDEAction( i18n( "&Colors..." ), "colorize.png", 0, this, TQT_SLOT( editColors() ), actionCollection(), "editcolors" );
-	( void ) new TDEAction( i18n( "&Coordinate System..." ), "coords.png", 0, this, TQT_SLOT( editAxes() ), actionCollection(), "editaxes" );
-	//  ( void ) new TDEAction( i18n( "&Grid..." ), "coords.png", 0, this, TQT_SLOT( editGrid() ), actionCollection(), "editgrid" );
-	( void ) new TDEAction( i18n( "&Scaling..." ), "scaling", 0, this, TQT_SLOT( editScaling() ), actionCollection(), "editscaling" );
-	( void ) new TDEAction( i18n( "&Fonts..." ), "fonts", 0, this, TQT_SLOT( editFonts() ), actionCollection(), "editfonts" );
+	( void ) new TDEAction( i18n( "&Colors..." ), "colorize.png", 0, this, TQ_SLOT( editColors() ), actionCollection(), "editcolors" );
+	( void ) new TDEAction( i18n( "&Coordinate System..." ), "coords.png", 0, this, TQ_SLOT( editAxes() ), actionCollection(), "editaxes" );
+	//  ( void ) new TDEAction( i18n( "&Grid..." ), "coords.png", 0, this, TQ_SLOT( editGrid() ), actionCollection(), "editgrid" );
+	( void ) new TDEAction( i18n( "&Scaling..." ), "scaling", 0, this, TQ_SLOT( editScaling() ), actionCollection(), "editscaling" );
+	( void ) new TDEAction( i18n( "&Fonts..." ), "fonts", 0, this, TQ_SLOT( editFonts() ), actionCollection(), "editfonts" );
 
-	( void ) new TDEAction( i18n( "Coordinate System I" ), "ksys1.png", 0, this, TQT_SLOT( slotCoord1() ), actionCollection(), "coord_i" );
-	( void ) new TDEAction( i18n( "Coordinate System II" ), "ksys2.png", 0, this, TQT_SLOT( slotCoord2() ), actionCollection(), "coord_ii" );
-	( void ) new TDEAction( i18n( "Coordinate System III" ), "ksys3.png", 0, this, TQT_SLOT( slotCoord3() ), actionCollection(), "coord_iii" );
+	( void ) new TDEAction( i18n( "Coordinate System I" ), "ksys1.png", 0, this, TQ_SLOT( slotCoord1() ), actionCollection(), "coord_i" );
+	( void ) new TDEAction( i18n( "Coordinate System II" ), "ksys2.png", 0, this, TQ_SLOT( slotCoord2() ), actionCollection(), "coord_ii" );
+	( void ) new TDEAction( i18n( "Coordinate System III" ), "ksys3.png", 0, this, TQ_SLOT( slotCoord3() ), actionCollection(), "coord_iii" );
 
 	// plot menu
-	( void ) new TDEAction( i18n( "&New Function Plot..." ), "newfunction", 0, this, TQT_SLOT( newFunction() ), actionCollection(), "newfunction" );
-	( void ) new TDEAction( i18n( "New Parametric Plot..." ), "newparametric", 0, this, TQT_SLOT( newParametric() ), actionCollection(), "newparametric" );
-	( void ) new TDEAction( i18n( "New Polar Plot..." ), "newpolar", 0, this, TQT_SLOT( newPolar() ), actionCollection(), "newpolar" );
-	( void ) new TDEAction( i18n( "Edit Plots..." ), "editplots", 0, this, TQT_SLOT( slotEditPlots() ), actionCollection(), "editplots" );
+	( void ) new TDEAction( i18n( "&New Function Plot..." ), "newfunction", 0, this, TQ_SLOT( newFunction() ), actionCollection(), "newfunction" );
+	( void ) new TDEAction( i18n( "New Parametric Plot..." ), "newparametric", 0, this, TQ_SLOT( newParametric() ), actionCollection(), "newparametric" );
+	( void ) new TDEAction( i18n( "New Polar Plot..." ), "newpolar", 0, this, TQ_SLOT( newPolar() ), actionCollection(), "newpolar" );
+	( void ) new TDEAction( i18n( "Edit Plots..." ), "editplots", 0, this, TQ_SLOT( slotEditPlots() ), actionCollection(), "editplots" );
 
 		// tools menu
-	TDEAction *mnuYValue =  new TDEAction( i18n( "&Get y-Value..." ), 0, this, TQT_SLOT( getYValue() ), actionCollection(), "yvalue" );
-	TDEAction *mnuMinValue = new TDEAction( i18n( "&Search for Minimum Value..." ), "minimum", 0, this, TQT_SLOT( findMinimumValue() ), actionCollection(), "minimumvalue" );
-	TDEAction *mnuMaxValue = new TDEAction( i18n( "&Search for Maximum Value..." ), "maximum", 0, this, TQT_SLOT( findMaximumValue() ), actionCollection(), "maximumvalue" );
-	TDEAction *mnuArea = new TDEAction( i18n( "&Calculate Integral" ), 0, this, TQT_SLOT( graphArea() ), actionCollection(), "grapharea" );
+	TDEAction *mnuYValue =  new TDEAction( i18n( "&Get y-Value..." ), 0, this, TQ_SLOT( getYValue() ), actionCollection(), "yvalue" );
+	TDEAction *mnuMinValue = new TDEAction( i18n( "&Search for Minimum Value..." ), "minimum", 0, this, TQ_SLOT( findMinimumValue() ), actionCollection(), "minimumvalue" );
+	TDEAction *mnuMaxValue = new TDEAction( i18n( "&Search for Maximum Value..." ), "maximum", 0, this, TQ_SLOT( findMaximumValue() ), actionCollection(), "maximumvalue" );
+	TDEAction *mnuArea = new TDEAction( i18n( "&Calculate Integral" ), 0, this, TQ_SLOT( graphArea() ), actionCollection(), "grapharea" );
 
-	connect( m_quickEdit, TQT_SIGNAL( returnPressed( const TQString& ) ), this, TQT_SLOT( slotQuickEdit( const TQString& ) ) );
+	connect( m_quickEdit, TQ_SIGNAL( returnPressed( const TQString& ) ), this, TQ_SLOT( slotQuickEdit( const TQString& ) ) );
 	KWidgetAction* quickEditAction =  new KWidgetAction( m_quickEdit, i18n( "Quick Edit" ), 0, this, 0, actionCollection(), "quickedit" );
 	quickEditAction->setWhatsThis( i18n( "Enter a simple function equation here.\n"
 	                                     "For instance: f(x)=x^2\nFor more options use Functions->Edit Plots... menu." ) );
 
-	view->mnuSliders[0] = new TDEToggleAction( i18n( "Show Slider 1" ), 0, this, TQT_SLOT( toggleShowSlider0() ), actionCollection(), TQString( "options_configure_show_slider_0" ).latin1() );
-	view->mnuSliders[1] = new TDEToggleAction( i18n( "Show Slider 2" ), 0, this, TQT_SLOT( toggleShowSlider1() ), actionCollection(), TQString( "options_configure_show_slider_1" ).latin1() );
-	view->mnuSliders[2] = new TDEToggleAction( i18n( "Show Slider 3" ), 0, this, TQT_SLOT( toggleShowSlider2() ), actionCollection(), TQString( "options_configure_show_slider_2" ).latin1() );
-	view->mnuSliders[3] = new TDEToggleAction( i18n( "Show Slider 4" ), 0, this, TQT_SLOT( toggleShowSlider3() ), actionCollection(), TQString( "options_configure_show_slider_3" ).latin1() );
+	view->mnuSliders[0] = new TDEToggleAction( i18n( "Show Slider 1" ), 0, this, TQ_SLOT( toggleShowSlider0() ), actionCollection(), TQString( "options_configure_show_slider_0" ).latin1() );
+	view->mnuSliders[1] = new TDEToggleAction( i18n( "Show Slider 2" ), 0, this, TQ_SLOT( toggleShowSlider1() ), actionCollection(), TQString( "options_configure_show_slider_1" ).latin1() );
+	view->mnuSliders[2] = new TDEToggleAction( i18n( "Show Slider 3" ), 0, this, TQ_SLOT( toggleShowSlider2() ), actionCollection(), TQString( "options_configure_show_slider_2" ).latin1() );
+	view->mnuSliders[3] = new TDEToggleAction( i18n( "Show Slider 4" ), 0, this, TQ_SLOT( toggleShowSlider3() ), actionCollection(), TQString( "options_configure_show_slider_3" ).latin1() );
 
 	// Popup menu
-	TDEAction *mnuHide = new TDEAction(i18n("&Hide") ,0,TQT_TQOBJECT(view), TQT_SLOT( mnuHide_clicked() ),actionCollection(),"mnuhide" );
+	TDEAction *mnuHide = new TDEAction(i18n("&Hide") ,0,view, TQ_SLOT( mnuHide_clicked() ),actionCollection(),"mnuhide" );
 	mnuHide->plug(m_popupmenu);
-	TDEAction *mnuRemove = new TDEAction(i18n("&Remove"),"edit-delete", 0,TQT_TQOBJECT(view), TQT_SLOT( mnuRemove_clicked() ),actionCollection(),"mnuremove"  );
+	TDEAction *mnuRemove = new TDEAction(i18n("&Remove"),"edit-delete", 0,view, TQ_SLOT( mnuRemove_clicked() ),actionCollection(),"mnuremove"  );
 	mnuRemove->plug(m_popupmenu);
-	TDEAction *mnuEdit = new TDEAction(i18n("&Edit"),"editplots", 0,TQT_TQOBJECT(view), TQT_SLOT( mnuEdit_clicked() ),actionCollection(),"mnuedit"  );
+	TDEAction *mnuEdit = new TDEAction(i18n("&Edit"),"editplots", 0,view, TQ_SLOT( mnuEdit_clicked() ),actionCollection(),"mnuedit"  );
 	mnuEdit->plug(m_popupmenu);
 	m_popupmenu->insertSeparator();
-	TDEAction *mnuCopy = new TDEAction(i18n("&Copy"), 0,TQT_TQOBJECT(view), TQT_SLOT( mnuCopy_clicked() ),actionCollection(),"mnucopy"  );
+	TDEAction *mnuCopy = new TDEAction(i18n("&Copy"), 0,view, TQ_SLOT( mnuCopy_clicked() ),actionCollection(),"mnucopy"  );
 	mnuCopy->plug(m_popupmenu);
-	TDEAction *mnuMove = new TDEAction(i18n("&Move"), 0,TQT_TQOBJECT(view), TQT_SLOT( mnuMove_clicked() ),actionCollection(),"mnumove"  );
+	TDEAction *mnuMove = new TDEAction(i18n("&Move"), 0,view, TQ_SLOT( mnuMove_clicked() ),actionCollection(),"mnumove"  );
 	mnuMove->plug(m_popupmenu);
 	m_popupmenu->insertSeparator();
 	mnuYValue->plug(m_popupmenu);
@@ -298,7 +298,7 @@ void MainDlg::slotExport()
 		if( url.fileName().right(4).lower()==".svg")
 		{
 			TQPicture pic;
-			view->draw(TQT_TQPAINTDEVICE(&pic), 2);
+			view->draw(&pic, 2);
 			if (url.isLocalFile() )
 				pic.save( url.prettyURL(0,KURL::StripFileProtocol), "SVG");
 			else
@@ -314,7 +314,7 @@ void MainDlg::slotExport()
 		else if( url.fileName().right(4).lower()==".bmp")
 		{
 			TQPixmap pic(100, 100);
-			view->draw(TQT_TQPAINTDEVICE(&pic), 3);
+			view->draw(&pic, 3);
 			if (url.isLocalFile() )
 				pic.save(  url.prettyURL(0,KURL::StripFileProtocol), "BMP");
 			else
@@ -330,7 +330,7 @@ void MainDlg::slotExport()
 		else if( url.fileName().right(4).lower()==".png")
 		{
 			TQPixmap pic(100, 100);
-			view->draw(TQT_TQPAINTDEVICE(&pic), 3);
+			view->draw(&pic, 3);
 			if (url.isLocalFile() )
 				pic.save( url.prettyURL(0,KURL::StripFileProtocol), "PNG");
 			else
@@ -408,7 +408,7 @@ void MainDlg::editColors()
 
 	// User edited the configuration - update your local copies of the
 	// configuration data
-	connect( colorsDialog, TQT_SIGNAL( settingsChanged() ), this, TQT_SLOT(updateSettings() ) );
+	connect( colorsDialog, TQ_SIGNAL( settingsChanged() ), this, TQ_SLOT(updateSettings() ) );
 	colorsDialog->show();
 }
 
@@ -420,7 +420,7 @@ void MainDlg::editAxes()
 		coordsDialog = new CoordsConfigDialog( view->parser(), m_parent);
 		// User edited the configuration - update your local copies of the
 		// configuration data
-		connect( coordsDialog, TQT_SIGNAL( settingsChanged() ), this, TQT_SLOT(updateSettings() ) );
+		connect( coordsDialog, TQ_SIGNAL( settingsChanged() ), this, TQ_SLOT(updateSettings() ) );
 	}
 	coordsDialog->show();
 }
@@ -433,7 +433,7 @@ void MainDlg::editScaling()
 	scalingDialog->addPage( new SettingsPageScaling( 0, "scalingSettings" ), i18n( "Scale" ), "scaling", i18n( "Edit Scaling" ) );
 	// User edited the configuration - update your local copies of the
 	// configuration data
-	connect( scalingDialog, TQT_SIGNAL( settingsChanged() ), this, TQT_SLOT(updateSettings() ) );
+	connect( scalingDialog, TQ_SIGNAL( settingsChanged() ), this, TQ_SLOT(updateSettings() ) );
 	scalingDialog->show();
 }
 
@@ -445,7 +445,7 @@ void MainDlg::editFonts()
 	fontsDialog->addPage( new SettingsPageFonts( 0, "fontsSettings" ), i18n( "Fonts" ), "fonts", i18n( "Edit Fonts" ) );
 	// User edited the configuration - update your local copies of the
 	// configuration data
-	connect( fontsDialog, TQT_SIGNAL( settingsChanged() ), this, TQT_SLOT(updateSettings() ) );
+	connect( fontsDialog, TQ_SIGNAL( settingsChanged() ), this, TQ_SLOT(updateSettings() ) );
 	fontsDialog->show();
 }
 
@@ -736,8 +736,8 @@ void MainDlg::toggleShowSlider(int const num)
 	if ( view->sliders[ num ] == 0 )
 	{
 		view->sliders[ num ] = new KSliderWindow( view, num);
-		connect( view->sliders[num]->slider, TQT_SIGNAL( valueChanged( int ) ), view, TQT_SLOT( drawPlot() ) );
-		connect( view->sliders[num], TQT_SIGNAL( windowClosed( int ) ), view, TQT_SLOT( sliderWindowClosed(int) ) );
+		connect( view->sliders[num]->slider, TQ_SIGNAL( valueChanged( int ) ), view, TQ_SLOT( drawPlot() ) );
+		connect( view->sliders[num], TQ_SIGNAL( windowClosed( int ) ), view, TQ_SLOT( sliderWindowClosed(int) ) );
 	}
 	if ( !view->sliders[ num ]->isShown() )
 		view->sliders[ num ]->show();
