@@ -252,7 +252,7 @@ class MultipleChoice;
 
 class KDE_EXPORT kvoctrainDoc : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
  public:
 
